import React, { Fragment } from 'react'
import { H4 } from '@pubsweet/ui'
import styled from 'styled-components'
import { th } from '@pubsweet/ui-toolkit'

import {
  Tabs,
  marginHelper,
  ContextualBox,
  ReviewersTable,
  InviteReviewers,
  ReviewerBreakdown,
} from '../'

const ReviewerDetails = ({
  fragment,
  invitations,
  onInviteReviewer,
  onResendReviewerInvite,
  onRevokeReviewerInvite,
}) => (
  <ContextualBox
    label="Reviewer details"
    rightChildren={<ReviewerBreakdown fitContent fragment={fragment} mr={1} />}
    startExpanded
  >
    <Tabs>
      {({ selectedTab, changeTab }) => (
        <Fragment>
          <TabsHeader>
            <TabButton
              ml={1}
              mr={1}
              onClick={() => changeTab(0)}
              selected={selectedTab === 0}
            >
              <H4>Reviewer Details</H4>
            </TabButton>
          </TabsHeader>
          {selectedTab === 0 && (
            <Fragment>
              <InviteReviewers
                modalKey="invite-reviewers"
                onInvite={onInviteReviewer}
              />
              <ReviewersTable
                invitations={invitations}
                onResendReviewerInvite={onResendReviewerInvite}
                onRevokeReviewerInvite={onRevokeReviewerInvite}
              />
            </Fragment>
          )}
        </Fragment>
      )}
    </Tabs>
  </ContextualBox>
)

export default ReviewerDetails

// #region styles
const TabButton = styled.div`
  align-items: center;
  border-bottom: ${props =>
    props.selected
      ? `4px solid ${props.theme.colorFurnitureHue}`
      : '4px solid transparent'};
  box-sizing: border-box;
  cursor: pointer;
  display: flex;
  justify-content: center;
  height: calc(${th('gridUnit')} * 5);

  ${marginHelper};

  ${H4} {
    padding: 0 ${th('gridUnit')};
  }
`

const TabsHeader = styled.div`
  align-items: center;
  border-bottom: 1px solid ${th('colorFurniture')};
  background-color: ${th('colorBackgroundHue2')};
  box-sizing: border-box;
  display: flex;
  justify-content: flex-start;

  padding: 0 calc(${th('gridUnit')} * 3);
`
// #endregion
